@@ -2,6 +2,8 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
+use std::fmt;
+
 pub struct Errors {
     pub messages: Vec<String>,
     pub nb_errors: usize,
@@ -11,8 +13,10 @@ impl Errors {
     pub fn has_errors(&self) -> bool {
         self.nb_errors > 0
     }
+}
 
-    pub fn to_string(&self) -> String {
-        self.messages.join("\n")
+impl fmt::Display for Errors {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str(&self.messages.join("\n"))
     }
 }
